Learn R Programming

peramo (version 0.1.3)

ensulizole: Biomarker Responses of the Blue Mussels to Organic UV Filters

Description

Biomarker Responses of the Blue Mussels to Organic UV Filters

Usage

mussel_SoS

mussel_gill

mussel_digest

Arguments

Format

An object of class data.frame with 15 rows and 7 columns.

An object of class data.frame with 120 rows and 24 columns.

An object of class data.frame with 120 rows and 24 columns.