Perform permutation-based hypothesis testing for randomized experiments as suggested in Ludbrook & Dudley (1998) tools:::Rd_expr_doi("10.2307/2685470") and Ernst (2004) tools:::Rd_expr_doi("10.1214/088342304000000396"), introduced in Pham et al. (2022) tools:::Rd_expr_doi("10.1016/j.chemosphere.2022.136736").
peramo: Permutation Tests for Randomization Model.
Copyright (C) 2022-2023 Duy Nghia Pham & Inna M. Sokolova
peramo
is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.
peramo is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
Public License for more details.
You should have received a copy of
the GNU General Public License along with peramo. If not, see
https://www.gnu.org/licenses/.
Duy Nghia Pham & Inna M. Sokolova